--[[
************************************************************************
Project				: Broker_AllXP
Author				: zhinjio
Project Revision	: r7
Project Date		: 20081209080958

File				: Broker_AllXP.lua
Commit Author		: zhinjio
Commit Revision		: 6
Commit Date			: 20081209080711
************************************************************************
Description	:
	Main addon file. 

TODO		:

************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]

local MODNAME = "AllXP"
local FULLNAME = "Broker_AllXP"
local AllXP = LibStub( "AceAddon-3.0" ):NewAddon( MODNAME, "AceEvent-3.0", "AceHook-3.0" )
local L = LibStub:GetLibrary( "AceLocale-3.0" ):GetLocale( MODNAME )
local AceConfig 		= LibStub("AceConfig-3.0")
local AceConfigReg 		= LibStub("AceConfigRegistry-3.0")
local AceConfigDialog 	= LibStub("AceConfigDialog-3.0")

_G[ MODNAME ] = AllXP
local addon = AllXP

local addonversion = "r7"
local addonauthor = "zhinjio"
local builddate = "20081209080958"

local modularOptions = {}
local tooltip
local LTT = LibStub:GetLibrary( "LibQTip-1.0" )

-- addon globals
addon.me = ""
addon.TPscanned = time()

local db

-- convert RAID_CLASS_COLORS to fontstring modifiers
--[[
		RAID_CLASS_COLORS = {
			["HUNTER"] = { r = 0.67, g = 0.83, b = 0.45 },
			["WARLOCK"] = { r = 0.58, g = 0.51, b = 0.79 },
			["PRIEST"] = { r = 1.0, g = 1.0, b = 1.0 },
			["PALADIN"] = { r = 0.96, g = 0.55, b = 0.73 },
			["MAGE"] = { r = 0.41, g = 0.8, b = 0.94 },
			["ROGUE"] = { r = 1.0, g = 0.96, b = 0.41 },
			["DRUID"] = { r = 1.0, g = 0.49, b = 0.04 },
			["SHAMAN"] = { r = 0.14, g = 0.35, b = 1.0 },
			["WARRIOR"] = { r = 0.78, g = 0.61, b = 0.43 },
			["DEATHKNIGHT"] = { r = 0.77, g = 0.12 , b = 0.23 },
		};
]]--
local myClassColors = {}
for k, v in pairs( RAID_CLASS_COLORS ) do
	myClassColors[k] = string.format( "%2x%2x%2x", v.r * 255, v.g * 255, v.b * 255 )
end

local sortingMethods = {
	[1] = L["Name"],
	[2] = L["Level"],
	[3] = L["Rested"],
}

function addon.Print( msg )
	local _, fh = DEFAULT_CHAT_FRAME:GetFont()
	fh = math.ceil( fh )
	local icon = "\124TInterface\\Addons\\" .. FULLNAME .. "\\icon:" .. fh .. "\124t"
	if ( msg ~= nil ) then
	   if( DEFAULT_CHAT_FRAME ) then
	      DEFAULT_CHAT_FRAME:AddMessage( icon .. " " .. MODNAME .. " : " .. msg, 0.6, 1.0, 1.0 )
	   end
	end
end

function addon.Debug( msg )
	if ( msg ~= nil ) then
		if ( db.options.display.debug ) then
			addon.Print( "DEBUG: " .. msg )
		end
	end
end

-- coloring agents
local function Orange( text )		return "|cffdea51c" .. text .. "|r" end
local function White( text )		return "|cffffffff" .. text .. "|r" end
local function Yellow( text )		return "|cffffff00" .. text .. "|r" end
local function Cyan( text )			return "|cff00ffff" .. text .. "|r" end
local function Biege( text )		return "|cffdfa050" .. text .. "|r" end
local function Pink( text )			return "|cffff8080" .. text .. "|r" end

local function ClassColor( text, class )
	-- if class coloring is off, just return white
	if ( ( db.options.display.classcolors ) and ( class ~= "" ) ) then
		return "|cff".. myClassColors[class] .. text .. "|r"
	else
		return White( text )
	end
end

local function Shorten( number )
	if ( db.options.display.shortnumbers ) then
		if ( number > 999999 ) then
			return string.format( "%.2fm", ( number / 1000000 ) )
		elseif ( number > 999 ) then
			return string.format( "%.2fk", ( number / 1000 ) )
		end
	end
	return string.format( "%d", number )
end

local function DHMS( secs )
	if ( secs == 0 ) then return L["??"] end
	local days = floor( secs / (60 * 60 * 24) ); secs = secs - ( days * 60 * 60 * 24 )
	local hours = floor( secs / (60 * 60) ); secs = secs - ( hours * 60 * 60 )
	local mins = floor( secs / 60 )
	local retval = ""
	if ( days ~= 0 ) then retval = days .. L["DAY_ABBREV"] end
	if ( hours ~= 0 ) then retval = retval .. hours .. L["HOURS_ABBREV"] end
	if ( mins ~= 0 ) then retval = retval .. mins .. L["MINS_ABBREV"] end
	return retval
end

local function HideTooltip()
	tooltip:SetScript( "OnLeave", nil )
	tooltip:Hide()
end

local function drawTooltip()
	tooltip:Hide()
	tooltip:Clear()

	-- tooltip display code here...

	local dbod = db.options.display
	-- 	Name	Level	CurrXP/MaxXP	XPPerc	RestedXP
	local numcols = 1
	local t = {}
	t[1] = "LEFT"
	if ( dbod.level ) then numcols = numcols + 1; table.insert( t, "CENTER" ) end
	if ( dbod.xpvalues ) then
		numcols = numcols + 3
		table.insert( t, "RIGHT" )
		table.insert( t, "CENTER" )
		table.insert( t, "LEFT" )
	end
	if ( dbod.xppercent ) then numcols = numcols + 1; table.insert( t, "CENTER" ) end
	if ( dbod.showTP ) then numcols = numcols + 1; table.insert( t, "CENTER" ) end
	if ( dbod.showTPTL ) then numcols = numcols + 1; table.insert( t, "CENTER" ) end
	if ( dbod.rested ) then numcols = numcols + 1; table.insert( t, "RIGHT" ) end
	tooltip:SetColumnLayout( numcols, unpack( t ) ) 
	
	tooltip:AddHeader( "a" )
	tooltip:SetCell( 1, 1, MODNAME, "CENTER", numcols )
	tooltip:AddLine( " " )

	-- Title line...
	t = nil; t = {}; t[1] = L["Name"]
	if ( dbod.level ) then table.insert( t, L["Level"] ) end
	if ( dbod.xpvalues ) then
		table.insert( t, " " )
		table.insert( t, L["XP"] )
		table.insert( t, " " )
	end
	if ( dbod.xppercent ) then table.insert( t, L["%"] ) end
	if ( dbod.showTP ) then table.insert( t, L["Played"] ) end
	if ( dbod.showTPTL ) then table.insert( t, L["This Level"] ) end
	if ( dbod.rested ) then table.insert( t, L["Rested"] ) end
	tooltip:AddHeader( unpack( t ) ) 
	
	-- sorting on non-numerically keyed tables is for to lol at. Thus, make my own. How sad.
	local dbf = addon.db.factionrealm
	local nDBF = nil; nDBF = {}
	for k, v in pairs( dbf ) do
		local t = {}
		-- remember, there might be missing elements if thats toon's db is old
		t.name = k
		if ( v.data ) then
			t.class = v.data.class or "PRIEST"
			t.timestamp = v.data.timestamp or 0
			t.level = v.data.level or 0
			t.XPmax = v.data.XPmax or 0
			t.XP = v.data.XP or 0
			t.rested = v.data.rested or 0
			t.totaltime = v.data.totaltime or 0
			t.leveltime = v.data.leveltime or 0
		else
			t.class = "PRIEST"
			t.timestamp = 0
			t.level = 0
			t.XPmax = 0
			t.XP = 0
			t.rested = 0
			t.totaltime = 0
			t.leveltime = 0
		end
		table.insert( nDBF, t )
	end
	-- Sort ...
	if ( db.options.display.sorting == 1 ) then			-- Name
		table.sort( nDBF, function( a, b ) return a.name < b.name end )
	elseif ( db.options.display.sorting == 2 ) then		-- Level
		table.sort( nDBF, function( a, b ) return a.level > b.level end ) 
	elseif ( db.options.display.sorting == 3 ) then		-- Rested
		table.sort( nDBF, function( a, b )
			aPerc = ( a.rested / a.XPmax ) * 100
			if ( a.timestamp ~= 0 ) then aPerc = aPerc + ( ( time() - a.timestamp ) / 5760 ) end
			if ( aPerc > 150 ) then aPerc = 150 end
			bPerc = ( b.rested / b.XPmax ) * 100
			if ( b.timestamp ~= 0 ) then bPerc = bPerc + ( ( time() - b.timestamp ) / 5760 ) end
			if ( bPerc > 150 ) then bPerc = 150 end
			return aPerc > bPerc
		end )
	else												-- Played
		table.sort( nDBF, function( a, b ) return a.totaltime > b.totaltime end )
	end
	for k, v in pairs( nDBF ) do
		t = nil; t = {}
		-- There's extra logic in here because the db versions can still be backrevved. Its unfortunate, but I 
		-- don't really have a nice, clean way around it.
		t[1] = ClassColor( v.name, v.class )

		if ( dbod.level ) then
			if ( v.level ~= 0 ) then
				table.insert( t, Yellow( v.level ) )
			else
				table.insert( t, Yellow( L["??"] ) )
			end
		end

		if ( dbod.xpvalues ) then
			if ( v.XP ~= 0 ) then
				table.insert( t, Cyan( Shorten( v.XP ) ) )
				table.insert( t, Cyan( "/" ) )
				table.insert( t, Cyan( Shorten( v.XPmax ) ) )
			else
				table.insert( t, Cyan( L["??"] ) )
				table.insert( t, Cyan( "/" ) )
				table.insert( t, Cyan( L["??"] ) )
			end
		end

		if ( dbod.xppercent ) then
			if ( v.XPmax ~= 0 ) then
				table.insert( t, Orange( string.format( "%.2f%%", ( ( v.XP / v.XPmax ) * 100 ) ) ) )
			else
				table.insert( t, Orange( L["??"] .. L["%"] ) )
			end
		end

		if ( dbod.showTP ) then
			table.insert( t, Yellow( DHMS( v.totaltime ) ) )
		end

		if ( dbod.showTPTL ) then
			table.insert( t, Cyan( DHMS( v.leveltime ) ) )
		end

		if ( dbod.rested ) then
			if ( ( v.rested ~= 0 ) and ( v.XPmax ~= 0 ) ) then
				local rPerc = ( v.rested / v.XPmax ) * 100
				if ( v.timestamp ~= 0 ) then
					rPerc = rPerc + ( ( time() - v.timestamp ) / 5760 )
				end
				if ( rPerc > 150 ) then rPerc = 150 end
				table.insert( t, Pink( string.format( "%.1f%%", rPerc ) ) )
			else
				table.insert( t, Pink(  L["??"] .. L["%"] ) ) 
			end
		end
		tooltip:AddLine( unpack( t ) )
	end

	tooltip:AddLine(" ")
--	tooltip:AddLine( L["Left-Click to cycle through maps"] )
	local lineNum = tooltip:AddLine( "b" )
	tooltip:SetCell( lineNum, 1, L["Click for Configuration"], "LEFT", numcols )
end

-- LDB stuff
local LDB = LibStub( "LibDataBroker-1.1" )
local launcher = LDB:NewDataObject( MODNAME, {
	type = "data source",
	text = "",
	label = FULLNAME,
	icon = "Interface\\Addons\\" .. FULLNAME .. "\\icon",
	OnClick = function( clickedframe, button )
				--[[
				if button == "RightButton" then
					addon:ShowConfig()
				else
					drawTooltip()
					tooltip:SmartAnchorTo( clickedframe )
					tooltip:Show()
				end
				]]--
				addon:ShowConfig()
	end,
	OnEnter = function ( self )
		drawTooltip()
		tooltip:EnableMouse()
		tooltip:SmartAnchorTo( self )
		tooltip:Show()
	end,
	OnLeave = function ( self )
		if MouseIsOver( tooltip ) then
			tooltip:SetScript( 'OnLeave', HideTooltip )
		else
			HideTooltip()
		end
	end,
} )

function addon.upgradeDB()
	local olddb = addon.db.factionrealm[addon.me]
	if ( olddb.options.display.dbVersion == "1.0" ) then
		-- original version
		olddb.data = {}
		olddb.data.level =0
		olddb.data.XP =0
		olddb.data.rested =0
		olddb.data.XPmax =0
		olddb.options.display.dbVersion = "1.1"
		addon.Print( string.format( L["Database upgraded to %s"], "1.1" ) )
	end
	if ( olddb.options.display.dbVersion == "1.1" ) then
		_, olddb.data.class = UnitClass( "player" )
		olddb.options.display.dbVersion = "1.2"
		addon.Print( string.format( L["Database upgraded to %s"], "1.2" ) )
	end
	if ( olddb.options.display.dbVersion == "1.2" ) then
		olddb.data.timestamp = 0
		olddb.options.display.dbVersion = "1.3"
		addon.Print( string.format( L["Database upgraded to %s"], "1.3" ) )
	end
	if ( olddb.options.display.dbVersion == "1.3" ) then
		olddb.options.display.shortnumbers = false
		olddb.options.display.xpvalues = true
		olddb.options.display.xppercent = true
		olddb.options.display.rested = true
		olddb.options.display.classcolors = true
		olddb.options.display.level = true
		olddb.options.display.dbVersion = "1.4"
		addon.Print( string.format( L["Database upgraded to %s"], "1.4" ) )
	end
	if ( olddb.options.display.dbVersion == "1.4" ) then
		olddb.options.display.showTP = false
		olddb.options.display.showTPTL = false
		olddb.data.totaltime = 0
		olddb.data.leveltime = 0
		olddb.options.display.dbVersion = "1.5"
		addon.Print( string.format( L["Database upgraded to %s"], "1.5" ) )
	end
	if ( olddb.options.display.dbVersion == "1.5" ) then
		olddb.options.display.hideTPchat = true
		olddb.options.display.dbVersion = "1.6"
		addon.Print( string.format( L["Database upgraded to %s"], "1.6" ) )
	end
end

local function HideTimePlayed( ... )
	addon.Debug( "raw hooked a time played call, ignoring" )
end

function addon:TIME_PLAYED_MSG( _, totalTime, lvlTime )
	addon.Debug( "Total time : " .. totalTime .. " / Level time : " .. lvlTime )
	db.data.totaltime = totalTime
	db.data.leveltime = lvlTime
	addon.TPscanned = time()
end

-- options stuff
local displayOptions = nil
local sortOptions = nil
local function giveDisplay()
	if (not displayOptions) then
		displayOptions = {
			order = 2,
			type = "group",
			name = L["Display Options"],
			desc = L["DISPLAY_OPTIONS_DESC"],
			args = {
				header1 = {
					order	= 21,
					type	= "header",
					name	= L["Display Options"],
				},
				desc = {
					order	= 22,
					type	= "description",
					name	= L["DISPLAY_OPTIONS_DESC"],
				},
				sound = {
					order	= 23,
					type	= "toggle",
					name	= L["Enable DEBUG"],
					desc	= L["DISPLAY_DEBUG_DESC"],
					get		= function() return db.options.display.debug end,
					set		= function() db.options.display.debug = not db.options.display.debug end,
				},
				tooltipscale = {
					order	= 24,
					type	= "range",
					name	= L["Tooltip Scale"],
					desc	= L["TOOLTIP_SCALE_DESC"],
					min		= .7,
					max		= 1.3,
					step	= .05,
					bigStep = .05,
					get		= function() return db.options.display.tipscale end,
					set		= function( info, v ) 
								db.options.display.tipscale = v
								tooltip:SetScale( v )
							  end,
				},
				xpvalues = {
					order	= 25,
					type	= "toggle",
					name	= L["Display XP Values"],
					desc	= L["DISPLAY_XPVALUES_DESC"],
					get		= function() return db.options.display.xpvalues end,
					set		= function() db.options.display.xpvalues = not db.options.display.xpvalues end,
				},
				xppercent = {
					order	= 26,
					type	= "toggle",
					name	= L["Display XP Percent"],
					desc	= L["DISPLAY_XPPERC_DESC"],
					get		= function() return db.options.display.xppercent end,
					set		= function() db.options.display.xppercent = not db.options.display.xppercent end,
				},
				rested = {
					order	= 27,
					type	= "toggle",
					name	= L["Display Rested XP"],
					desc	= L["DISPLAY_RESTED_DESC"],
					get		= function() return db.options.display.rested end,
					set		= function() db.options.display.rested = not db.options.display.rested end,
				},
				shortnums = {
					order	= 28,
					type	= "toggle",
					name	= L["Enable Short Numbers"],
					desc	= L["DISPLAY_SHORTNUMS_DESC"],
					get		= function() return db.options.display.shortnumbers end,
					set		= function() db.options.display.shortnumbers = not db.options.display.shortnumbers end,
				},
				classcolors = {
					order	= 29,
					type	= "toggle",
					name	= L["Display Class Colors"],
					desc	= L["DISPLAY_CLASSCOLORS_DESC"],
					get		= function() return db.options.display.classcolors end,
					set		= function() db.options.display.classcolors = not db.options.display.classcolors end,
				},
				level = {
					order	= 30,
					type	= "toggle",
					name	= L["Display Level"],
					desc	= L["DISPLAY_LEVEL_DESC"],
					get		= function() return db.options.display.level end,
					set		= function() db.options.display.level = not db.options.display.level end,
				},
				timeplayed = {
					order	= 31,
					type	= "toggle",
					name	= L["Display Time Played"],
					desc	= L["DISPLAY_TIMEPLAYED_DESC"],
					get		= function() return db.options.display.showTP end,
					set		= function() db.options.display.showTP = not db.options.display.showTP end,
				},
				levelplayed = {
					order	= 32,
					type	= "toggle",
					name	= L["Display Time This Level"],
					desc	= L["DISPLAY_TIMELEVEL_DESC"],
					get		= function() return db.options.display.showTPTL end,
					set		= function() db.options.display.showTPTL = not db.options.display.showTPTL end,
				},
				hideTPchat = {
					order	= 33,
					type	= "toggle",
					name	= L["Hide Time Played in chat"],
					desc	= L["DISPLAY_HIDETPCHAT_DESC"],
					get		= function() return db.options.display.hideTPchat end,
					set		= function() db.options.display.hideTPchat = not db.options.display.hideTPchat end,
				},
				sorting = {
					order	= 34,
					type	= "select",
					name	= L["Sorting"],
					desc	= L["SORTING_DESC"],
					get		= function() return db.options.display.sorting end,
					set		= function( info, value ) db.options.display.sorting = value end,
					values	= {
						[1] = L["Name"],
						[2] = L["Level"],
						[3] = L["Rested"],
						[4] = L["Played"],
					},
				},
			},
		}
	end
	return displayOptions
end

local function giveSort()
	if (not sortOptions) then
		sortOptions = {
			order = 3,
			type = "group",
			name = L["Sorting Options"],
			desc = L["SORTING_OPTIONS_DESC"],
			args = {
				header1 = {
					order	= 31,
					type	= "header",
					name	= L["Sorting Options"],
				},
				desc = {
					order	= 32,
					type	= "description",
					name	= L["SORTING_OPTIONS_DESC"],
				},
				sName = {
					order	= 33,
					type	= "toggle",
					name	= L["Sort by Name"],
					desc	= L["SORT_NAME_DESC"],
					get		= function() return db.options.display.debug end,
					set		= function() db.options.display.debug = not db.options.display.debug end,
				},
				sLevel = {
					order	= 34,
					type	= "toggle",
					name	= L["Sort by Level"],
					desc	= L["SORT_LEVEL_DESC"],
					get		= function() return db.options.display.classcolors end,
					set		= function() db.options.display.classcolors = not db.options.display.classcolors end,
				},
				sRested = {
					order	= 35,
					type	= "toggle",
					name	= L["Sort by Rested XP"],
					desc	= L["SORT_RESTED_DESC"],
					get		= function() return db.options.display.level end,
					set		= function() db.options.display.level = not db.options.display.level end,
				},
			},
		}
	end
	return displayOptions
end

local options = nil
local function fullOptions()
	if (not options) then
		options = {
			type = "group",
			name = MODNAME,
			args = {
				general = {
					order	= 1,
					type	= "group",
					name	= L["General Information"],
					desc	= L["GENERAL_INFO_DESC"],
					args	= {
						header1 = {
							order	= 11,
							type	= "header",
							name	= L["General Information"],
						},
						desc = {
							order	= 12,
							type	= "description",
							name	= L["GENERAL_INFO_DESC"],
						},
						author = {
							order	= 13,
							type	= "description",
							name	= L["Author : "] .. addonauthor .. "\n",
						},
						version = {
							order	= 14,
							type	= "description",
							name	= L["Version : "] .. addonversion .. "\n",
						},
						builddate = {
							order	= 15,
							type	= "description",
							name	= L["Build Date : "] .. builddate .. "\n",
						},
						dbversion = {
							order	= 15,
							type	= "description",
							name	= L["Database Version : "] .. db.options.display.dbVersion .. "\n",
						},
						translators = {
							order	= 16,
							type	= "description",
							name	= string.format( L["Helpful Translators (thank you) : %s"], " \n" )
						},
					},
				},
			},
		}
	end
	
	for k,v in pairs(modularOptions) do
		options.args[k] = (type(v) == "function") and v() or v
	end

	return options
end

function addon:SetupOptions()
	AceConfigReg:RegisterOptionsTable(MODNAME, fullOptions)
	self.optionsFrame = AceConfigDialog:AddToBlizOptions(MODNAME, nil, nil, "general")

	-- Fill up our modular options...
	self:RegisterModuleOptions("Display", giveDisplay(), L["Display Options"])
end

function addon:RegisterModuleOptions(name, optionsTable, displayName)
	modularOptions[name] = optionsTable
	self.optionsFrame[name] = AceConfigDialog:AddToBlizOptions(MODNAME, displayName, MODNAME, name)
end

function addon:ShowConfig()
	-- Open the profiles tab before, so the menu expands
	InterfaceOptionsFrame_OpenToCategory( self.optionsFrame["Display"] )
end

function addon.startScanning()
	local totalElapsed = 0

	if ( not AllXP_ScannerFrame ) then
		AllXP_ScannerFrame = CreateFrame( "Frame" )
	end

	AllXP_ScannerFrame:SetScript( "OnUpdate", function(self, elapsed)
		totalElapsed = totalElapsed + elapsed
		-- update once every 30 seconds. I may change this later
		if ( totalElapsed < 3 ) then
			-- update our current db values
			db.data.level = UnitLevel( "player" )
			db.data.rested = GetXPExhaustion() or 0
			db.data.XP = UnitXP( "player" )
			db.data.XPmax = UnitXPMax( "player" )
			db.data.timestamp = time()
			_, db.data.class = UnitClass( "player" )
			db.data.totaltime = db.data.totaltime + ( time() - addon.TPscanned )
			db.data.leveltime = db.data.leveltime + ( time() - addon.TPscanned )
			addon.TPscanned = time()
		elseif ( totalElapsed > 30 ) then
			totalElapsed = 0
		end
	end )
end

function addon:OnInitialize()
	-- Do Frame Creation stuff here
	-- addon:CreateFrames()
end

function addon:OnEnable()
    -- Called when the addon is loaded
	addon.me = UnitName( "player" )

	self.db = LibStub( "AceDB-3.0" ):New( MODNAME .. "_DB", nil, "Default" )
	-- do we have any data yet; for this toon? If not, init its table
	if not ( self.db.factionrealm[addon.me] ) then
		self.db.factionrealm[addon.me] = {
		-- Your saved variables stuff here
			options = {
				display = {
					debug = false,
					tipscale = 1,
					dbVersion = "1.6",
					shortnumbers = false,
					xpvalues = true,
					xppercent = true,
					rested = true,
					classcolors = true,
					level = true,
					showTP = false,
					showTPTL = false,
					hideTPchat = true,
					sorting = 3,
				},
			},
			data = {
				class = "",
				level = 0,
				XP = 0,
				rested = 0,
				XPmax = 0,
				timestamp = 0,
				totaltime = 0,
				leveltime = 0,
			},
		}
	else
		-- check if we need to upgrade the db
		addon.upgradeDB()
	end
	db = self.db.factionrealm[addon.me]

	-- tooltip setup and scaling
	tooltip = LTT:Acquire( MODNAME.."TT", 3, "LEFT", "CENTER", "RIGHT" ) -- or GameTooltip
	tooltip:SetScale( db.options.display.tipscale )

	addon:SetupOptions()
	-- Event listeners
    -- addon:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
	addon:RegisterEvent( "TIME_PLAYED_MSG" )
	if ( db.options.display.hideTPchat == true ) then
		addon:RawHook( "ChatFrame_DisplayTimePlayed", HideTimePlayed, true )
	end
	RequestTimePlayed()

	-- Kick off our onupdate frame to start watching our XP
	addon.startScanning()
end

--[[
************************************************************************
CHANGELOG:

12/06/08 : 
	Initial version
************************************************************************
]]--